OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" დირექტორიაში ჩაწერა ვერ ხერხდება!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "ეს ჩვეულებრივ გამოსწორებადია ვებსერვერისთვის კონფიგურაციის დირექტორიაზე წერის უფლებების მინიჭებით",
    "See %s" : "იხილეთ %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "ეს ჩვეულებრივ გამოსწორებადია ვებსერვერისთვის კონფიგურაციის დირექტორიაზე წერის უფლებების მინიჭებით. იხილეთ %s",
    "Sample configuration detected" : "სანიმუშო კონფუგარცია აღმოჩენილია",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "დადგენილია რომ მოხდა სანიმუშო კონფიგურაციის დაკოპირება. ამან შეიძლება გააფუჭოს თქვენი ინსტალაცია და არაა მხარდაჭერილი. გთხოვთ config.php-ში ცვლილებების შეტანამდე გაეცნოთ დოკუმენტაციას.",
    "%1$s and %2$s" : "%1$s და %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s და %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s და %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s და %5$s",
    "Education Edition" : "საგანმანათლებლო გამოცემა",
    "Enterprise bundle" : "ენტერპრაის კონსტრუქცია",
    "Groupware bundle" : "ჯგუფური კონსტრუქცია",
    "Social sharing bundle" : "სოციალური გაზიარების შეკვრა",
    "PHP %s or higher is required." : "PHP %s ან უფრო მაღალია საჭირო.",
    "PHP with a version lower than %s is required." : "საჭიროა PHP-ს %s-ზე მცირე ვერსია.",
    "%sbit or higher PHP required." : "საჭიროა PHP %s ბიტით ან მეტით.",
    "Following databases are supported: %s" : "მხარდაჭერილია შემდეგი მონაცემთა ბაზები: %s",
    "The command line tool %s could not be found" : "command-line ხელსაწყო %s ვერ იქნა ნაპოვნი",
    "The library %s is not available." : "ბიბლიოთეკა %s ვერ იქნა ნაპოვნი.",
    "Following platforms are supported: %s" : "მხარდაჭერია შემდეგი პლატფორმები: %s",
    "Server version %s or higher is required." : "საჭიროა სერვერი ვერსიით %s ან მეტი.",
    "Server version %s or lower is required." : "საჭიროა სერვერი ვერსიით %s ან ნაკლები.",
    "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
    "Authentication" : "აუტენტიფიკაცია",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Invalid image" : "არასწორი სურათი",
    "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
    "today" : "დღეს",
    "tomorrow" : "ხვალ",
    "yesterday" : "გუშინ",
    "_in %n day_::_in %n days_" : ["%n დღეში","%n დღეში"],
    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
    "next month" : "შემდეგი თვე",
    "last month" : "გასულ თვეში",
    "_in %n month_::_in %n months_" : ["%n თვეში","%n თვეში"],
    "_%n month ago_::_%n months ago_" : ["%n თვის წინ","%n თვის წინ"],
    "next year" : "შემდეგი წელი",
    "last year" : "გასულ წელს",
    "_in %n year_::_in %n years_" : ["%n წელიწადში","%n წელიწადში"],
    "_%n year ago_::_%n years ago_" : ["%n წლის წინ","%n წლის წინ"],
    "_in %n hour_::_in %n hours_" : ["%n საათში","%n საათში"],
    "_%n hour ago_::_%n hours ago_" : ["%n საათის წინ","%n საათის წინ"],
    "_in %n minute_::_in %n minutes_" : ["%n წუთში","%n წუთში"],
    "_%n minute ago_::_%n minutes ago_" : ["%n წუთის წინ","%n წუთის წინ"],
    "in a few seconds" : "რამდენიმე წამში",
    "seconds ago" : "წამის წინ",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "მოდული ID-ით: %s არ არსებობს. გთხოვთ აამოქმედოთ ის აპლიკაციების პარამეტრებში ან დაუკავშირდეთ ადმინისტრატორს.",
    "File name is a reserved word" : "ფაილის სახელი რეზერვირებული სიტყვაა",
    "File name contains at least one invalid character" : "ფაილის სახელი მოიცავს დაუშვებელ სიმბოლოს",
    "File name is too long" : "ფაილის სახელი ზედმეტად გრძელია",
    "Dot files are not allowed" : "წერტილოვანი ფაილები არაა ნებადართლი",
    "Empty filename is not allowed" : "ცარიელი ფაილის სახელი არაა ნებადართული",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან appinfo ფაილი არ იკითხება.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან ის ამ სერვერის ვერსიასთან არაა თავსებადი.",
    "__language_name__" : "ქართული",
    "This is an automatically sent email, please do not reply." : "ეს ელ-წერილი გამოგზავნილია ავტომატურად, გთხოვთ არ უპასუხოთ.",
    "Help" : "დახმარება",
    "Apps" : "აპლიკაციები",
    "Settings" : "პარამეტრები",
    "Log out" : "გასვლა",
    "Users" : "მომხმარებლები",
    "Unknown user" : "ამოუცნობი მომხმარებელი",
    "Basic settings" : "ძირითადი პარამეტრები",
    "Sharing" : "გაზიარება",
    "Security" : "უსაფრთხოება",
    "Additional settings" : "დამატებითი პარამეტრები",
    "Personal info" : "პირადი ინფორმაცია",
    "%s enter the database username and name." : "%s შეიყვანეთ მონაცემთა ბაზის მომხმარებლის სახელი და სახელი.",
    "%s enter the database username." : "%s შეიყვანეთ ბაზის მომხმარებლის სახელი.",
    "%s enter the database name." : "%s შეიყვანეთ ბაზის სახელი.",
    "%s you may not use dots in the database name" : "%s არ მიუთითოთ წერტილი ბაზის სახელში",
    "Oracle connection could not be established" : "Oracle კავშირი ვერ დამყარდა",
    "Oracle username and/or password not valid" : "Oracle მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
    "PostgreSQL username and/or password not valid" : "PostgreSQL მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
    "You need to enter details of an existing account." : "საჭიროა შეიყვანოთ არსებული ანგარიშის დეტალები.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X არაა მხარდაჭერილი და %s ამ პლატფორმაზე სწორად არ იმუშავებს. გამოიყენეთ საკუთარი რისკით!",
    "For the best results, please consider using a GNU/Linux server instead." : "საუკეთესო შედეგებისთვის სანაცვლოდ გამოიყენეთ GNU/Linux სერვერი.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "როგორც ჩანს ეს %s ინსტანცია მოქმედებს 32-ბიტიან PHP გარემოზე და open_basedir php.ini-ში კონფიგურირებულია. ეს 4 გბ-ზე დიდ ფაილებთან გამოიწვევს პრობლემს და რეკომედირებული არაა.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "გთხოვთ ამოშალოთ open_basedir პარამეტრი php.ini-დან ან გადახვიდეთ 64-ბიტიან PHP-ზე.",
    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
    "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
    "Can't create or write into the data directory %s" : "მონაცემების დირექტრიის შექმნა ან მასში ჩაწერა ვერ მოხერხდა %s",
    "Invalid Federated Cloud ID" : "არასწორი ფედერალური ქლაუდ ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "გაზიარების ბექენდმა %s-მ მოქმედებაში უნდა მოიყვანოს ინტეფეისი OCP\\Share_Backend",
    "Sharing backend %s not found" : "გაზიარების ბექენდი %s ვერ იქნა ნაპოვნი",
    "Sharing backend for %s not found" : "გაზიარების ბექენდი %s-თვის ვერ იქნა ნაპოვნი",
    "Open »%s«" : "გახნსნა »%s«",
    "You are not allowed to share %s" : "თქვენ არ გაქვთ უფლება გააზიაროთ %s",
    "Can’t increase permissions of %s" : "%s-ის უფლებების გაზრდა ვერ მოხერხდა",
    "Files can’t be shared with delete permissions" : "ფაილები გაუქმების უფლებით ვერ გაზიარდება",
    "Files can’t be shared with create permissions" : "ფაილები შექმნის უფლებებით ვერ გაზიარდება",
    "Expiration date is in the past" : "ვადის ამოწურვის თარიღი წარსულშია",
    "Can’t set expiration date more than %s days in the future" : "ვადის ამოწურვის თარიღი %s დღეზე მეტი მომავალში ვერ იქნება",
    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
    "The requested share does not exist anymore" : "მოთხოვნილი გაზიარება მეტი აღარ არსებობს",
    "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sun." : "კვი.",
    "Mon." : "ორშ.",
    "Tue." : "სამ.",
    "Wed." : "ოთხ.",
    "Thu." : "ხუთ.",
    "Fri." : "პარ.",
    "Sat." : "შაბ.",
    "Su" : "კვ",
    "Mo" : "ორ",
    "Tu" : "სა",
    "We" : "ოთ",
    "Th" : "ხუ",
    "Fr" : "პა",
    "Sa" : "შა",
    "January" : "იანვარი",
    "February" : "თებერვალი",
    "March" : "მარტი",
    "April" : "აპრილი",
    "May" : "მაისი",
    "June" : "ივნისი",
    "July" : "ივლისი",
    "August" : "აგვისტო",
    "September" : "სექტემბერი",
    "October" : "ოქტომბერი",
    "November" : "ნოემბერი",
    "December" : "დეკემბერი",
    "Jan." : "იან.",
    "Feb." : "თებ.",
    "Mar." : "მარ.",
    "Apr." : "აპრ.",
    "May." : "მაი.",
    "Jun." : "ივნ.",
    "Jul." : "ივლ.",
    "Aug." : "აგვ.",
    "Sep." : "სექ.",
    "Oct." : "ოქტ.",
    "Nov." : "ნოე.",
    "Dec." : "დეკ.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "მომხმარებლის სახელში დაშვებულია მხოლოდ შემდეგი ნიშნები: \"a-z\", \"A-Z\", \"0-9\", და \"_.@-'\"",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "Username contains whitespace at the beginning or at the end" : "მომხმარებლის სახელი დასაწყისსში ან დასასრულში მოიცავს სიცარიელეს",
    "Username must not consist of dots only" : "მომხმარებლის სახელი ვერ იქნება შემდგარი მხოლოდ წერტილებისგან",
    "A valid password must be provided" : "უნდა მიუთითოთ სწორი პაროლი",
    "The username is already being used" : "ესეთი მომხმარებლის სახელი უკვე არსებობს",
    "Could not create user" : "მომხმარებლის შექმნა ვერ მოხერხდა",
    "User disabled" : "მომხმარებელი გათიშულია",
    "Login canceled by app" : "აპლიკაციამ ლოგინი უარყო",
    "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "File is currently busy, please try again later" : "ფაილი ამჟამად დაკავებულია, გთხოვთ მოგვიანებით სცადოთ ახლიდან",
    "Can't read file" : "ფაილის წაკითხვა ვერ მოხერხდა",
    "Application is not enabled" : "აპლიკაცია არ არის აქტიური",
    "Authentication error" : "აუტენტიფიკაციის შეცდომა",
    "Token expired. Please reload page." : "ტოკენს ვადა გაუვიდა. გთხოვთ განაახლოთ გვერდი.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "მონაცემთა ბაზის დრაივერები (sqlite, mysql, ან postgresql) დაყენებული არაა.",
    "Cannot write into \"config\" directory" : "კონფიგურაციის \"config\" დირექტორიაში ჩაწერა ვერ მოხერხდა",
    "Cannot write into \"apps\" directory" : "აპლიკაციების \"apps\" დირექტორიაში ჩაწერა ვერ მოხერხდა",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "ეს ჩვეულებრივ გამოსწორებადია ვებსერვერისთვის აპლიკაციების დირექტორიაზე წერის უფლების მინიჭებით ან appstore-ის კონფიგურაციის ფაილით გათიშვით. იხილეთ %s",
    "Cannot create \"data\" directory" : "\"data\" დირექორია ვერ შეიქმნა",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "ეს ჩვეულებრივ გამოსწორებადია ვებსერვერისთვის root დირექტორიაზე წერის უფლებების მინიჭებით. იხილეთ %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "უფლებები ჩვეულებრივ გამოსწორებადია ვებსერვერისთვის root დირექტორიაზე წერის უფლებების მინიჭებით. იხილეთ %s",
    "Setting locale to %s failed" : "ლოკალიზაციის %s-ზე დაყენება ვერ მოხერხდა",
    "Please install one of these locales on your system and restart your webserver." : "გთხოვთ დააყენოთ ამ ლოკალიზაციებიდან ერთ-ერთი და გადატვირთოთ ვებ-სერვერი.",
    "Please ask your server administrator to install the module." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს დააყენოს მოდული.",
    "PHP module %s not installed." : "PHP მოდული %s არაა დაყენებული.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP პარამეტრი \"%s\" არ არის დაყენებული \"%s\"-ზე.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "ამ პარამეტრის დაყენება php.ini-ში Nextcloud-ს გაუშვებს ახლიდან",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload მოსალოდნელი მნიშვნელობის \"0\"-ის ნაცვლად დაყენებულია \"%s\"-ზე",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "ამ პრობლემის მოსაგვარებლად php.ini-ში <code>mbstring.func_overload</code> დააყენეთ <code>0</code>-ზე",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "საჭიროა libxml2 ვერსიით 2.7.0 ან მეტი. ახლა დაყენებულია %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "ამ პრობლემის მოსაგვარებლად განაახლეთ libxml2 ვერსია და გადატვირთეთ თქვენი ვებ-სერვერი.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "როგორც ჩანს PHP დაყენებულია ისე, რომ შიდა დოკუმენტური ბლოკები წაშალოს. ეს რამდენიმე მთავარ აპლიკაციას გახდის მიუწვდომელს.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ეს შესაძლოა გამოწვეული იყოს ისეთი კეშით/აქსელერატორით როგორიცაა Zend OPcache ან eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP მოდულები დაყენდა, მაგრამ მაინც ჩამოწერილია როგორც არმყოფები?",
    "Please ask your server administrator to restart the web server." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს გადატვირთოს ვებ-სერვერი.",
    "PostgreSQL >= 9 required" : "საჭიროა PostgreSQL >= 9",
    "Please upgrade your database version" : "გთხოვთ განაახლოთ თქვენი მონაცემთა ბაზის ვერსია",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი.",
    "Your data directory is readable by other users" : "თქვენი მონაცემების დირექტორია სხვა მომხარებლების მიერ კითხვადია",
    "Your data directory must be an absolute path" : "თქვენი მონაცემების დირექტორია უნდა იყოს აბოლუტური მისამართი",
    "Check the value of \"datadirectory\" in your configuration" : "თქვენს კონფიგურაციაში შეამოწმეთ \"datadiretory\"-ის მნიშვნელობა",
    "Your data directory is invalid" : "თქვენი მონაცემების დირექტორია არაა სწორი",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "დარწმუნდით რომ ფაილი სახელად \".ocdata\" მონაცემების დირექტორიის საწყისშია.",
    "Could not obtain lock type %d on \"%s\"." : "ჩაკეთვის ტიპის %d მოძიება \"%s\"-ზე ვერ მოხერხდა.",
    "Storage unauthorized. %s" : "საცავი არაავტორიზირებულია. %s",
    "Storage incomplete configuration. %s" : "საცავის არასრული კონფიგურაცია. %s",
    "Storage connection error. %s" : "საცავის კავშირის შეცდომა. %s",
    "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
    "Storage connection timeout. %s" : "საცავის კავშირის დროის ამოწურვა. %s",
    "Create" : "შექმნა",
    "Change" : "შეცვლა",
    "Delete" : "გაუქმება",
    "Share" : "გაზიარება",
    "Unlimited" : "ულიმიტო",
    "Verifying" : "მოწმდება",
    "Verifying …" : "მოწმდება …",
    "Verify" : "დამოწმება",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s-ის გაზიარება არ მოხერხდა, რადგანაც ბექენდი არ იღებს გაზიარებებს სახეობით %s",
    "Sharing %s failed, because the file does not exist" : "%s-ის გაზიარება არ მოხერხდა, რადგან ფაილი არ არსებობს",
    "Sharing %s failed, because you can not share with yourself" : "%s-ის გაზიარება ვერ მოხერხდა, რადგან საკუთარ თავთან ვერ გააზიარებთ",
    "You need to provide a password to create a public link, only protected links are allowed" : "საზოგადო ბმულის შექმნისთვის აუცილებელია პაროლის მითთება, მხადაჭერილია მხოლოდ დაცული ბმულები",
    "Sharing %s failed, because sharing with links is not allowed" : "%s-ის გაზიარება არ მოხერხდა, ბმულებით გაზიარება არაა ნებადართული",
    "Not allowed to create a federated share with the same user" : "იმავე მომხმარებელთან ფედერალური გაზიარება ვერ შეიქმნება",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "ვადის ამოწურვის დროის მითთება ვერ ხერხდება. გაზიარებები გაზიარების შემდეგ %s-ზე ადრე ვერ გაუქმდებიან",
    "Cannot set expiration date. Expiration date is in the past" : "ვადის ამოწურვის დროის მითითება ვერ ხერხდება. ვადის გასვლის დრო წარსულია",
    "Sharing failed, because the user %s is the original sharer" : "გაზიარება ვერ მოხერხდა, რადგან მომხმარებელი %s თავდაპირველი გამზიარებელია",
    "Sharing %s failed, because resharing is not allowed" : "%s-გაზიარება ვერ მოხერხდა, რადგან ხელახალი გაზიარება ნებადართული არაა",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s-ის გაზიარება ვერ მოხერხდა, რადგან ფაილი კეშში ვერ მოიძებნა"
},
"nplurals=2; plural=(n!=1);");
